@@ -118,7 +118,9 @@ backup_fmt = {
     'local':
     {'title': 'Local', 'len': 5, 'fmt': '%5s', 'get': lambda e: 'Yes' if d(e, ['local']) else 'No'},
     'size':
-    {'title': 'Size', 'len': 5, 'fmt': '%5d', 'get': lambda e: d(e, ['size'])},
+    {'title': 'Size', 'len': 15, 'fmt': '%5d', 'get': lambda e: d(e, ['size'], 0)},
+    'state':
+    {'title': 'State', 'len': 10, 'fmt': '%10s', 'get': lambda e: d(e, ['state'])},
     'timestamp':
     {'title': 'Timestamp', 'len': 20, 'fmt': '%-20s',
      'get': lambda e: datetime.fromtimestamp(d(e, ['timestamp'])/1000000).isoformat()},
@@ -177,7 +179,7 @@ def snapshots_list(args):
 
 def backups_list(args):
     l = args.endpoint.list_backups(args.vmuuid)
-    l = sorted(l, key=lambda e: e['timestamp'])
+    l = sorted(l, key=lambda e: d(e, ['timestamp'], 0))
     if args.H:
         header(args)
     fmt = mk_fmt_str(args)
@@ -362,7 +364,6 @@ class VM(Entity):
         parser_svcadm_enable.set_defaults(func=svcadm_action)
         parser_svcadm_enable.add_argument('service', help='Service to enable')
 
-
         parser_svcadm_disable = subparsers_svcadm.add_parser('disable', help='enables a service')
         parser_svcadm_disable.set_defaults(action='disable')
         parser_svcadm_disable.set_defaults(func=svcadm_action)
@@ -373,8 +374,6 @@ class VM(Entity):
         parser_svcadm_clear.set_defaults(func=svcadm_action)
         parser_svcadm_clear.add_argument('service', help='Service to en or clear')
 
-
-
         parser_vms_delete = subparsers_vms.add_parser('delete', help='deletes a VM')
         parser_vms_delete.add_argument('-l', action='store_true', default=False,
                                        help='Delete the vm only on the hypervisor.')
